@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -20,13 +20,13 @@
 //! \brief C++ API module wrapper
 //! \author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+#include <pymobius.h>
 #include "filesystem_iso.h"
 #include "filesystem.h"
-#include "api_datetime.h"
 #include "api_metadata.h"
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: tp_dealloc
+//! \brief filesystem_iso: tp_dealloc
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static void
 tp_dealloc (filesystem_filesystem_iso_o *self)
@@ -36,7 +36,7 @@ tp_dealloc (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: volume_descr_version getter
+//! \brief filesystem_iso: volume_descr_version getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_volume_descr_version (filesystem_filesystem_iso_o *self)
@@ -45,25 +45,25 @@ tp_getter_volume_descr_version (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: system_id getter
+//! \brief filesystem_iso: system_id getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_system_id (filesystem_filesystem_iso_o *self)
 {
-  return PyString_FromString (self->obj->get_system_id ().c_str ());
+  return PyString2_from_std_string (self->obj->get_system_id ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: volume_id getter
+//! \brief filesystem_iso: volume_id getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_volume_id (filesystem_filesystem_iso_o *self)
 {
-  return PyString_FromString (self->obj->get_volume_id ().c_str ());
+  return PyString2_from_std_string (self->obj->get_volume_id ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: volume_space_size getter
+//! \brief filesystem_iso: volume_space_size getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_volume_space_size (filesystem_filesystem_iso_o *self)
@@ -72,7 +72,7 @@ tp_getter_volume_space_size (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: volume_set_size getter
+//! \brief filesystem_iso: volume_set_size getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_volume_set_size (filesystem_filesystem_iso_o *self)
@@ -81,7 +81,7 @@ tp_getter_volume_set_size (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: volume_sequence_number getter
+//! \brief filesystem_iso: volume_sequence_number getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_volume_sequence_number (filesystem_filesystem_iso_o *self)
@@ -90,7 +90,7 @@ tp_getter_volume_sequence_number (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: logical_block_size getter
+//! \brief filesystem_iso: logical_block_size getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_logical_block_size (filesystem_filesystem_iso_o *self)
@@ -99,7 +99,7 @@ tp_getter_logical_block_size (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: path_table_size getter
+//! \brief filesystem_iso: path_table_size getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_path_table_size (filesystem_filesystem_iso_o *self)
@@ -108,7 +108,7 @@ tp_getter_path_table_size (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: type_l_path_table getter
+//! \brief filesystem_iso: type_l_path_table getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_type_l_path_table (filesystem_filesystem_iso_o *self)
@@ -117,7 +117,7 @@ tp_getter_type_l_path_table (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: type_l_optional_path_table getter
+//! \brief filesystem_iso: type_l_optional_path_table getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_type_l_optional_path_table (filesystem_filesystem_iso_o *self)
@@ -126,7 +126,7 @@ tp_getter_type_l_optional_path_table (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: type_m_path_table getter
+//! \brief filesystem_iso: type_m_path_table getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_type_m_path_table (filesystem_filesystem_iso_o *self)
@@ -135,7 +135,7 @@ tp_getter_type_m_path_table (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: type_m_optional_path_table getter
+//! \brief filesystem_iso: type_m_optional_path_table getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_type_m_optional_path_table (filesystem_filesystem_iso_o *self)
@@ -144,106 +144,106 @@ tp_getter_type_m_optional_path_table (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: volume_set_id getter
+//! \brief filesystem_iso: volume_set_id getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_volume_set_id (filesystem_filesystem_iso_o *self)
 {
-  return PyString_FromString (self->obj->get_volume_set_id ().c_str ());
+  return PyString2_from_std_string (self->obj->get_volume_set_id ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: publisher_id getter
+//! \brief filesystem_iso: publisher_id getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_publisher_id (filesystem_filesystem_iso_o *self)
 {
-  return PyString_FromString (self->obj->get_publisher_id ().c_str ());
+  return PyString2_from_std_string (self->obj->get_publisher_id ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: data_preparer_id getter
+//! \brief filesystem_iso: data_preparer_id getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_data_preparer_id (filesystem_filesystem_iso_o *self)
 {
-  return PyString_FromString (self->obj->get_data_preparer_id ().c_str ());
+  return PyString2_from_std_string (self->obj->get_data_preparer_id ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: application_id getter
+//! \brief filesystem_iso: application_id getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_application_id (filesystem_filesystem_iso_o *self)
 {
-  return PyString_FromString (self->obj->get_application_id ().c_str ());
+  return PyString2_from_std_string (self->obj->get_application_id ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: copyright_file_id getter
+//! \brief filesystem_iso: copyright_file_id getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_copyright_file_id (filesystem_filesystem_iso_o *self)
 {
-  return PyString_FromString (self->obj->get_copyright_file_id ().c_str ());
+  return PyString2_from_std_string (self->obj->get_copyright_file_id ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: abstract_file_id getter
+//! \brief filesystem_iso: abstract_file_id getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_abstract_file_id (filesystem_filesystem_iso_o *self)
 {
-  return PyString_FromString (self->obj->get_abstract_file_id ().c_str ());
+  return PyString2_from_std_string (self->obj->get_abstract_file_id ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: bibliographic_file_id getter
+//! \brief filesystem_iso: bibliographic_file_id getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_bibliographic_file_id (filesystem_filesystem_iso_o *self)
 {
-  return PyString_FromString (self->obj->get_bibliographic_file_id ().c_str ());
+  return PyString2_from_std_string (self->obj->get_bibliographic_file_id ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: creation_time getter
+//! \brief filesystem_iso: creation_time getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_creation_time (filesystem_filesystem_iso_o *self)
 {
-  return PyDateTime_from_datetime (self->obj->get_creation_time ());
+  return mobius::py::pydatetime_from_datetime (self->obj->get_creation_time ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: last_modification_time getter
+//! \brief filesystem_iso: last_modification_time getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_last_modification_time (filesystem_filesystem_iso_o *self)
 {
-  return PyDateTime_from_datetime (self->obj->get_last_modification_time ());
+  return mobius::py::pydatetime_from_datetime (self->obj->get_last_modification_time ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: expiration_time getter
+//! \brief filesystem_iso: expiration_time getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_expiration_time (filesystem_filesystem_iso_o *self)
 {
-  return PyDateTime_from_datetime (self->obj->get_expiration_time ());
+  return mobius::py::pydatetime_from_datetime (self->obj->get_expiration_time ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: effective_time getter
+//! \brief filesystem_iso: effective_time getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_effective_time (filesystem_filesystem_iso_o *self)
 {
-  return PyDateTime_from_datetime (self->obj->get_effective_time ());
+  return mobius::py::pydatetime_from_datetime (self->obj->get_effective_time ());
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: file_structure_version getter
+//! \brief filesystem_iso: file_structure_version getter
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
 tp_getter_file_structure_version (filesystem_filesystem_iso_o *self)
@@ -252,7 +252,7 @@ tp_getter_file_structure_version (filesystem_filesystem_iso_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: getters and setters structure
+//! \brief filesystem_iso: getters and setters structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyGetSetDef tp_getset[] =
 {
@@ -404,7 +404,7 @@ static PyGetSetDef tp_getset[] =
 };
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//!\brief filesystem_iso: type structure
+//! \brief filesystem_iso: type structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyTypeObject filesystem_filesystem_iso_t =
 {
