@@ -20,9 +20,9 @@
 //! \file credhist_entry.cc C++ API <i>mobius.turing.dpapi.credhist_entry</i> class wrapper
 //! \author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+#include <pymobius.h>
 #include "credhist_entry.h"
 #include "module.h"
-#include "api.h"
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief Check if object type is <i>credhist_entry</i>
@@ -96,29 +96,7 @@ tp_getter_guid (turing_dpapi_credhist_entry_o *self)
 
   try
     {
-      ret = PyString_from_std_string (self->obj->get_guid ());
-    }
-  catch (const std::exception& e)
-    {
-      PyErr_SetString (PyExc_Exception, e.what ());
-    }
-
-  return ret;
-}
-
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>size</i> Attribute getter
-//! \param self Object
-//! \return <i>size</i> attribute
-// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-static PyObject *
-tp_getter_size (turing_dpapi_credhist_entry_o *self)
-{
-  PyObject *ret = nullptr;
-
-  try
-    {
-      ret = PyLong_FromUnsignedLong (self->obj->get_size ());
+      ret = PyString2_from_std_string (self->obj->get_guid ());
     }
   catch (const std::exception& e)
     {
@@ -228,7 +206,7 @@ tp_getter_salt (turing_dpapi_credhist_entry_o *self)
 
   try
     {
-      ret = PyBytes_from_bytearray (self->obj->get_salt ());
+      ret = mobius::py::pybytes_from_bytearray (self->obj->get_salt ());
     }
   catch (const std::exception& e)
     {
@@ -250,7 +228,29 @@ tp_getter_sid (turing_dpapi_credhist_entry_o *self)
 
   try
     {
-      ret = PyString_from_std_string (self->obj->get_sid ());
+      ret = PyString2_from_std_string (self->obj->get_sid ());
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>cipher_text</i> Attribute getter
+//! \param self Object
+//! \return <i>cipher_text</i> attribute
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_getter_cipher_text (turing_dpapi_credhist_entry_o *self)
+{
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pybytes_from_bytearray (self->obj->get_cipher_text ());
     }
   catch (const std::exception& e)
     {
@@ -272,7 +272,7 @@ tp_getter_hash_sha1 (turing_dpapi_credhist_entry_o *self)
 
   try
     {
-      ret = PyBytes_from_bytearray (self->obj->get_hash_sha1 ());
+      ret = mobius::py::pybytes_from_bytearray (self->obj->get_hash_sha1 ());
     }
   catch (const std::exception& e)
     {
@@ -283,18 +283,18 @@ tp_getter_hash_sha1 (turing_dpapi_credhist_entry_o *self)
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief <i>hash_md4</i> Attribute getter
+//! \brief <i>hash_ntlm</i> Attribute getter
 //! \param self Object
-//! \return <i>hash_md4</i> attribute
+//! \return <i>hash_ntlm</i> attribute
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 static PyObject *
-tp_getter_hash_md4 (turing_dpapi_credhist_entry_o *self)
+tp_getter_hash_ntlm (turing_dpapi_credhist_entry_o *self)
 {
   PyObject *ret = nullptr;
 
   try
     {
-      ret = PyBytes_from_bytearray (self->obj->get_hash_md4 ());
+      ret = mobius::py::pybytes_from_bytearray (self->obj->get_hash_ntlm ());
     }
   catch (const std::exception& e)
     {
@@ -323,13 +323,6 @@ static PyGetSetDef tp_getset[] =
     (char *) "GUID",
     NULL
   },
-  {
-    (char *) "size",
-    (getter) tp_getter_size,
-    (setter) 0,
-    (char *) "Size",
-    NULL
-  },
   {
     (char *) "type",
     (getter) tp_getter_type,
@@ -372,6 +365,13 @@ static PyGetSetDef tp_getset[] =
     (char *) "SID",
     NULL
   },
+  {
+    (char *) "cipher_text",
+    (getter) tp_getter_cipher_text,
+    (setter) 0,
+    (char *) "Cipher text",
+    NULL
+  },
   {
     (char *) "hash_sha1",
     (getter) tp_getter_hash_sha1,
@@ -380,10 +380,10 @@ static PyGetSetDef tp_getset[] =
     NULL
   },
   {
-    (char *) "hash_md4",
-    (getter) tp_getter_hash_md4,
+    (char *) "hash_ntlm",
+    (getter) tp_getter_hash_ntlm,
     (setter) 0,
-    (char *) "MD4 hash value",
+    (char *) "NTLM hash value",
     NULL
   },
   {NULL, NULL, NULL, NULL, NULL} // sentinel
@@ -399,7 +399,7 @@ tp_f_decrypt_with_key (turing_dpapi_credhist_entry_o *self, PyObject *args)
 {
   // parse input args
   const std::uint8_t * arg_key_buffer;
-  int arg_key_size;
+  Py_ssize_t arg_key_size;
 
   if (!PyArg_ParseTuple (args, "s#", &arg_key_buffer, &arg_key_size))
     return nullptr;
@@ -411,7 +411,7 @@ tp_f_decrypt_with_key (turing_dpapi_credhist_entry_o *self, PyObject *args)
 
   try
     {
-      ret = PyBool_FromLong (self->obj->decrypt_with_key (arg_key));
+      ret = mobius::py::pybool_from_bool (self->obj->decrypt_with_key (arg_key));
     }
   catch (const std::exception& e)
     {
@@ -432,7 +432,7 @@ tp_f_decrypt_with_password_hash (turing_dpapi_credhist_entry_o *self, PyObject *
 {
   // parse input args
   const std::uint8_t * arg_password_hash_buffer;
-  int arg_password_hash_size;
+  Py_ssize_t arg_password_hash_size;
 
   if (!PyArg_ParseTuple (args, "s#", &arg_password_hash_buffer, &arg_password_hash_size))
     return nullptr;
@@ -444,7 +444,7 @@ tp_f_decrypt_with_password_hash (turing_dpapi_credhist_entry_o *self, PyObject *
 
   try
     {
-      ret = PyBool_FromLong (self->obj->decrypt_with_password_hash (arg_password_hash));
+      ret = mobius::py::pybool_from_bool (self->obj->decrypt_with_password_hash (arg_password_hash));
     }
   catch (const std::exception& e)
     {
@@ -474,7 +474,31 @@ tp_f_decrypt_with_password (turing_dpapi_credhist_entry_o *self, PyObject *args)
 
   try
     {
-      ret = PyBool_FromLong (self->obj->decrypt_with_password (arg_password));
+      ret = mobius::py::pybool_from_bool (self->obj->decrypt_with_password (arg_password));
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_Exception, e.what ());
+      return nullptr;
+    }
+
+  return ret;
+}
+
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+//! \brief <i>is_decrypted</i> method implementation
+//! \param self Object
+//! \param args Argument list
+// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+static PyObject *
+tp_f_is_decrypted (turing_dpapi_credhist_entry_o *self, PyObject *)
+{
+  // execute C++ function
+  PyObject *ret = nullptr;
+
+  try
+    {
+      ret = mobius::py::pybool_from_bool (self->obj->is_decrypted ());
     }
   catch (const std::exception& e)
     {
@@ -508,6 +532,12 @@ static PyMethodDef tp_methods[] =
     METH_VARARGS,
     "Decrypt entry using password"
   },
+  {
+    (char *) "is_decrypted",
+    (PyCFunction) tp_f_is_decrypted,
+    METH_VARARGS,
+    "Check if entry is decrypted"
+  },
   {NULL, NULL, 0, NULL} // sentinel
 };
 
